ldas.iiif
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

This file will become your README and also the index of your
documentation.

## Install

``` sh
pip install ldas.iiif
```

## How to use

Fill me in please! Don’t forget code examples:

``` python
1+1
```

    2
